@@ -13,6 +13,8 @@ class JSONEncoder(json.JSONEncoder):
     def default(self, obj):
         if isinstance(obj, datetime):
             return obj.strftime('%Y-%m-%d %H:%M:%S')
+        if isinstance(obj, bytes):
+            return obj.decode('utf8')
         base_type = (str, int, float, dict, list)
         if (not isinstance(obj, base_type) and
                 hasattr(obj, '__str__')):
